Evaluation
==========

Classes and pipelines for evaluating generated 3D conformers.

Evaluation Classes
------------------

.. automodule:: shepherd_score.evaluations.evaluate.evals
   :members:
   :undoc-members:
   :show-inheritance:

Evaluation Pipelines
--------------------

.. automodule:: shepherd_score.evaluations.evaluate.pipelines
   :members:
   :undoc-members:
   :show-inheritance:
